@@ -1,24 +1,13 @@
 /*
 * Copyright 2016 Nu-book Inc.
 * Copyright 2016 ZXing authors
-*
-* Licensed under the Apache License, Version 2.0 (the "License");
-* you may not use this file except in compliance with the License.
-* You may obtain a copy of the License at
-*
-*      http://www.apache.org/licenses/LICENSE-2.0
-*
-* Unless required by applicable law or agreed to in writing, software
-* distributed under the License is distributed on an "AS IS" BASIS,
-* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-* See the License for the specific language governing permissions and
-* limitations under the License.
 */
+// SPDX-License-Identifier: Apache-2.0
 
 #include "BitSource.h"
 
 #include "ByteArray.h"
-#include "ZXContainerAlgorithms.h"
+#include "ZXAlgorithms.h"
 
 #include <stdexcept>
 
@@ -30,10 +19,9 @@ BitSource::available() const
 	return 8 * (Size(_bytes) - _byteOffset) - _bitOffset;
 }
 
-int
-BitSource::readBits(int numBits)
+static int ReadBitsImpl(int numBits, const ByteArray& _bytes, int available, int& _byteOffset, int& _bitOffset)
 {
-	if (numBits < 1 || numBits > 32 || numBits > available()) {
+	if (numBits < 1 || numBits > 32 || numBits > available) {
 		throw std::out_of_range("BitSource::readBits: out of range");
 	}
 
@@ -74,4 +62,16 @@ BitSource::readBits(int numBits)
 	return result;
 }
 
+int BitSource::readBits(int numBits)
+{
+	return ReadBitsImpl(numBits, _bytes, available(), _byteOffset, _bitOffset);
+}
+
+int BitSource::peekBits(int numBits) const
+{
+	int bitOffset = _bitOffset;
+	int byteOffset = _byteOffset;
+	return ReadBitsImpl(numBits, _bytes, available(), byteOffset, bitOffset);
+}
+
 } // ZXing
