@@ -1,23 +1,12 @@
 /*
 * Copyright 2016 Nu-book Inc.
-*
-* Licensed under the Apache License, Version 2.0 (the "License");
-* you may not use this file except in compliance with the License.
-* You may obtain a copy of the License at
-*
-*      http://www.apache.org/licenses/LICENSE-2.0
-*
-* Unless required by applicable law or agreed to in writing, software
-* distributed under the License is distributed on an "AS IS" BASIS,
-* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-* See the License for the specific language governing permissions and
-* limitations under the License.
 */
+// SPDX-License-Identifier: Apache-2.0
 
 #include "BarcodeFormat.h"
 #include "MultiFormatWriter.h"
 #include "BitMatrix.h"
-#include "CharacterSetECI.h"
+#include "CharacterSet.h"
 
 #include <string>
 #include <memory>
@@ -66,11 +55,12 @@ WriteResult generateBarcode(std::wstring text, std::string format, std::string e
 		if (barcodeFormat == BarcodeFormat::None)
 			return {"Unsupported format: " + format};
 
+		// TODO: use new writer API
 		MultiFormatWriter writer(barcodeFormat);
 		if (margin >= 0)
 			writer.setMargin(margin);
 
-		CharacterSet charset = CharacterSetECI::CharsetFromName(encoding.c_str());
+		CharacterSet charset = CharacterSetFromString(encoding);
 		if (charset != CharacterSet::Unknown)
 			writer.setEncoding(charset);
 
